agentle.agents.whatsapp.models.whatsapp\_video\_message
=======================================================

.. automodule:: agentle.agents.whatsapp.models.whatsapp_video_message

   
   .. rubric:: Classes

   .. autosummary::
   
      WhatsAppMediaMessage
      WhatsAppMessageType
      WhatsAppVideoMessage
   